# This has nothing to do with the library, these are just
# Some informations you need to know

def about():
    return("GEOMATH is a Library developed for handling\
    Analytical Geometry on Python 3.X")

def version():
    return("Version: 0.1.2.3")
