from distutils.core import setup
setup(
  name = 'geomath',
  packages = ['geomath'],
  version = '0.1.2.3',
  description = 'A Mathematic Library to Handle Eucliedan Geometry',
  author = 'Vinicius Mesel',
  author_email = 'me@vmesel.com',
  url = 'https://github.com/vmesel/GeoMath/',
  download_url = 'https://www.github.com/vmesel/GeoMath/tarball/0.1.2.3',
  keywords = ['geometry', 'math', 'euclidean geometry'],
  classifiers = [],
)
